Iterators
=======================

Iterator methods for Trees and DAGs.

.. list-table:: Iterator Methods
   :widths: 20 40 40
   :header-rows: 1

   * - Data Structure
     - Algorithm
     - Description
   * - Tree
     - Pre-order Traversal
     - Depth-First Search, NLR
   * - Tree
     - Post-Order Traversal
     - Depth-First Search, LRN
   * - Tree
     - Level-Order Traversal
     - Breadth-First Search
   * - Tree
     - Level-Order Group Traversal
     - Breadth-First Search
   * - DAG
     - General
     - Depth-First Search

.. automodule:: bigtree.utils.iterators
   :members:
   :show-inheritance:
